@@ -397,6 +397,9 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
   const char
     *artifact;
 
+  const Quantum
+    *p;
+
   MagickBooleanType
     status;
 
@@ -407,9 +410,6 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
   RectangleInfo
     bounds;
 
-  const Quantum
-    *p;
-
   ssize_t
     y;
 
@@ -420,7 +420,7 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
   artifact=GetImageArtifact(image,"trim:percent-background");
   if (artifact != (const char *) NULL)
     return(GetEdgeBoundingBox(image,exception));
-  artifact=GetImageArtifact(image, "trim:edges");
+  artifact=GetImageArtifact(image,"trim:edges");
   if (artifact == (const char *) NULL)
     {
       bounds.width=(size_t) (image->columns == 1 ? 1 : 0);
@@ -473,6 +473,7 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
     exception);
   if (p != (const Quantum *) NULL)
     GetPixelInfoPixel(image,p,&target[2]);
+  GetPixelInfo(image,&target[3]);
   p=GetCacheViewVirtualPixels(image_view,(ssize_t) image->columns-1,(ssize_t)
     image->rows-1,1,1,exception);
   if (p != (const Quantum *) NULL)
@@ -485,15 +486,15 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
+    const Quantum
+      *magick_restrict q;
+
     PixelInfo
       pixel;
 
     RectangleInfo
       bounding_box;
 
-    const Quantum
-      *magick_restrict q;
-
     ssize_t
       x;
 
@@ -732,13 +733,13 @@ void TraceConvexHull(PointInfo *vertices,size_t number_vertices,
   PointInfo
     **chain;
 
-  ssize_t
-    i;
-
   size_t
     demark,
     n;
 
+  ssize_t
+    i;
+
   /*
     Construct the upper and lower hulls: rightmost to leftmost counterclockwise.
   */
@@ -921,7 +922,7 @@ MagickExport size_t GetImageDepth(const Image *image,ExceptionInfo *exception)
   for (i=0; i < (ssize_t) number_threads; i++)
     current_depth[i]=1;
   if ((image->storage_class == PseudoClass) &&
-      (image->alpha_trait == UndefinedPixelTrait))
+      ((image->alpha_trait & BlendPixelTrait) == 0))
     {
       for (i=0; i < (ssize_t) image->colors; i++)
       {
@@ -1511,7 +1512,7 @@ MagickExport ImageType GetImageType(const Image *image)
   assert(image->signature == MagickCoreSignature);
   if (image->colorspace == CMYKColorspace)
     {
-      if (image->alpha_trait == UndefinedPixelTrait)
+      if ((image->alpha_trait & BlendPixelTrait) == 0)
         return(ColorSeparationType);
       return(ColorSeparationAlphaType);
     }
@@ -1734,7 +1735,7 @@ MagickExport ImageType IdentifyImageType(const Image *image,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->colorspace == CMYKColorspace)
     {
-      if (image->alpha_trait == UndefinedPixelTrait)
+      if ((image->alpha_trait & BlendPixelTrait) == 0)
         return(ColorSeparationType);
       return(ColorSeparationAlphaType);
     }
@@ -1829,7 +1830,7 @@ MagickExport MagickBooleanType IsImageMonochrome(const Image *image)
 %  IsImageOpaque() returns MagickTrue if none of the pixels in the image have
 %  an alpha value other than OpaqueAlpha (QuantumRange).
 %
-%  Will return true immediatally is alpha channel is not available.
+%  Will return true immediately is alpha channel is not available.
 %
 %  The format of the IsImageOpaque method is:
 %
@@ -1865,7 +1866,7 @@ MagickExport MagickBooleanType IsImageOpaque(const Image *image,
   assert(image->signature == MagickCoreSignature);
   if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  if (image->alpha_trait == UndefinedPixelTrait)
+  if ((image->alpha_trait & BlendPixelTrait) == 0)
     return(MagickTrue);
   image_view=AcquireVirtualCacheView(image,exception);
   for (y=0; y < (ssize_t) image->rows; y++)
@@ -2183,7 +2184,7 @@ MagickExport MagickBooleanType SetImageType(Image *image,const ImageType type,
     {
       if (IsGrayImageType(image->type) == MagickFalse)
         status=TransformImageColorspace(image,GRAYColorspace,exception);
-      if (image->alpha_trait == UndefinedPixelTrait)
+      if ((image->alpha_trait & BlendPixelTrait) == 0)
         (void) SetImageAlphaChannel(image,OpaqueAlphaChannel,exception);
       break;
     }
@@ -2208,7 +2209,7 @@ MagickExport MagickBooleanType SetImageType(Image *image,const ImageType type,
 
       if (IssRGBCompatibleColorspace(image->colorspace) == MagickFalse)
         status=TransformImageColorspace(image,sRGBColorspace,exception);
-      if (image->alpha_trait == UndefinedPixelTrait)
+      if ((image->alpha_trait & BlendPixelTrait) == 0)
         (void) SetImageAlphaChannel(image,OpaqueAlphaChannel,exception);
       channel_mask=SetImageChannelMask(image,AlphaChannel);
       (void) BilevelImage(image,(double) QuantumRange/2.0,exception);
@@ -2222,7 +2223,7 @@ MagickExport MagickBooleanType SetImageType(Image *image,const ImageType type,
     {
       if (IssRGBCompatibleColorspace(image->colorspace) == MagickFalse)
         status=TransformImageColorspace(image,sRGBColorspace,exception);
-      if (image->alpha_trait == UndefinedPixelTrait)
+      if ((image->alpha_trait & BlendPixelTrait) == 0)
         (void) SetImageAlphaChannel(image,OpaqueAlphaChannel,exception);
       quantize_info=AcquireQuantizeInfo(image_info);
       quantize_info->colorspace=TransparentColorspace;
@@ -2245,7 +2246,7 @@ MagickExport MagickBooleanType SetImageType(Image *image,const ImageType type,
         status=TransformImageColorspace(image,sRGBColorspace,exception);
       if (image->storage_class != DirectClass)
         status=SetImageStorageClass(image,DirectClass,exception);
-      if (image->alpha_trait == UndefinedPixelTrait)
+      if ((image->alpha_trait & BlendPixelTrait) == 0)
         (void) SetImageAlphaChannel(image,OpaqueAlphaChannel,exception);
       break;
     }
@@ -2264,7 +2265,7 @@ MagickExport MagickBooleanType SetImageType(Image *image,const ImageType type,
         status=TransformImageColorspace(image,CMYKColorspace,exception);
       if (image->storage_class != DirectClass)
         status=SetImageStorageClass(image,DirectClass,exception);
-      if (image->alpha_trait == UndefinedPixelTrait)
+      if ((image->alpha_trait & BlendPixelTrait) == 0)
         status=SetImageAlphaChannel(image,OpaqueAlphaChannel,exception);
       break;
     }
