@@ -244,7 +244,7 @@ static MagickBooleanType ReadHEICExifProfile(Image *image,
       if ((length > 2) && 
           ((memcmp(datum,"\xff\xd8",2) == 0) ||
            (memcmp(datum,"\xff\xe1",2) == 0)) &&
-           memcmp(datum+length-2,"\xff\xd9",2) == 0)
+           (memcmp(datum+length-2,"\xff\xd9",2) == 0))
         SetStringInfoLength(exif_profile,length-2);
       /*
         Skip to actual Exif payload.
@@ -1248,7 +1248,7 @@ static MagickBooleanType WriteHEICImage(const ImageInfo *image_info,
     if (status == MagickFalse)
       break;
     chroma=lossless != MagickFalse ? heif_chroma_444 : heif_chroma_420;
-    if (image->alpha_trait == BlendPixelTrait)
+    if ((image->alpha_trait & BlendPixelTrait) != 0)
       {
         if (IssRGBCompatibleColorspace(image->colorspace) == MagickFalse)
           status=TransformImageColorspace(image,sRGBColorspace,exception);
